==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PoleData.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PoleData extends GenericDPSObject {
    /**
     * POLE_DATA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * POLE_DATA.WARTOSC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date wartosc;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_DATA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLE_DATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLE_DATA.WARTOSC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getWartosc() {
        return wartosc;
    }

    /**
     * POLE_DATA.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWartosc(Date wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleData other = (PoleData) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PoleData.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PoleData extends GenericDPSObject {
    /**
     * POLE_DATA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * POLE_DATA.WARTOSC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date wartosc;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return POLE_DATA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * POLE_DATA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return POLE_DATA.WARTOSC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getWartosc() {
        return wartosc;
    }

    /**
     * POLE_DATA.WARTOSC
     *
     * @param wartosc
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWartosc(Date wartosc) {
        this.wartosc = wartosc;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PoleData other = (PoleData) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getWartosc() == null ? other.getWartosc() == null : this.getWartosc().equals(other.getWartosc()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getWartosc() == null) ? 0 : getWartosc().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", wartosc=").append(wartosc);
        sb.append("]");
        return sb.toString();
    }
}
